# carga_datos.py
import pandas as pd

def cargar_csv_desde_url(url: str) -> pd.DataFrame | None:
    """
    Carga un archivo CSV desde una URL y lo devuelve como un DataFrame.

    Parámetros:
        url (str): URL del archivo CSV.

    Retorna:
        pd.DataFrame: DataFrame con los datos cargados o None si hay error.
    """
    try:
        df = pd.read_csv(url)
        print("✅ Archivo cargado correctamente.")
        return df
    except Exception as e:
        print(f"❌ Error al cargar el archivo desde la URL: {e}")
        return None

def guardar_csv_local(df: pd.DataFrame, nombre_archivo: str) -> None:
    """
    Guarda un DataFrame en un archivo CSV localmente.

    Parámetros:
        df (pd.DataFrame): DataFrame que se desea guardar.
        nombre_archivo (str): Nombre del archivo CSV de salida.
    """
    try:
        df.to_csv(nombre_archivo, index=False)
        print(f"✅ Archivo guardado como '{nombre_archivo}'.")
    except Exception as e:
        print(f"❌ Error al guardar el archivo: {e}")

# Este bloque solo se ejecutará si cargas este script directamente
if __name__ == "__main__":
    url = "https://seguridadvial.semovi.cdmx.gob.mx/wp-content/themes/semovi-seguridad-vial/data/dataset.csv"
    df = cargar_csv_desde_url(url)
    if df is not None:
        guardar_csv_local(df, "dataset_guardado.csv")



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# Información de los autores
author_names = "@may, @juan"
author_email = "may@example.com, juan@example.com"

setuptools.setup(
    name="SMVLibreria",  # nombre de la librería (como se instalará)
    version="1.0.1",
    author=author_names,
    author_email=author_email,
    description="Librería para analizar datos de seguridad vial de SEMOVI: conteo por periodos y tasas de crecimiento",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/greenmay99/semovi_libreria",
    project_urls={
        "Repositorio": "https://github.com/greenmay99/semovi_libreria",
        "Documentación": "https://github.com/greenmay99/semovi_libreria#readme",
    },
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering :: Information Analysis",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.10",
    install_requires=[
        "pandas",
        "requests"
    ],
)
